<?php

namespace FiloBlu\ExtMailChimp\Helper;

use Magento\Framework\App\Helper\AbstractHelper;
use Magento\Framework\App\Helper\Context;
use Magento\Framework\App\ResourceConnection;
use Magento\Newsletter\Model\Subscriber;
use Magento\Store\Model\ScopeInterface;

/**
 * Class Data
 * @package FiloBlu\ExtMailChimp\Helper
 */
class Data extends AbstractHelper
{
    /** @var string */
    const XML_MERGEVARS = 'mailchimp/general/filoblu_subscriber_map_fields';
    /**
     * @var \Ebizmarts\MailChimp\Helper\Data
     */
    private $mailchimpHelper;
    /**
     * @var ResourceConnection
     */
    private $resourceConnection;

    /**
     * Data constructor.
     * @param Context $context
     * @param ResourceConnection $resourceConnection
     * @param \Ebizmarts\MailChimp\Helper\Data $mailchimpHelper
     */
    public function __construct(Context $context,
                                ResourceConnection $resourceConnection,
                                \Ebizmarts\MailChimp\Helper\Data $mailchimpHelper)
    {
        parent::__construct($context);
        $this->mailchimpHelper = $mailchimpHelper;
        $this->resourceConnection = $resourceConnection;
    }

    /**
     * @param Subscriber $subscriber
     * @param $storeId
     * @return array
     */
    public function getMergeVars(Subscriber $subscriber, $storeId)
    {
        $value = $this->scopeConfig->getValue(self::XML_MERGEVARS, ScopeInterface::SCOPE_STORES, $storeId);

        if($value === null)
        {
            return [];
        }
       $map = $this->mailchimpHelper->unserialize($value);

        $result = [];

        foreach ($map as $magentoField => $mailchimpField)
        {
            $result[$mailchimpField] = $subscriber->getData($magentoField);
        }
        return $result;
    }

    /**
     * @return array
     */
    public function getSubscriberAttributes()
    {
        $data = $this->resourceConnection
            ->getConnection()
            ->describeTable('filoblu_newsletter_subscriber_info');

        $result = [];

        if (!isset($data['type'])){
            // Type is a dynamic field, calculated on the fly
            $data['type']['COLUMN_NAME'] = 'type';
        }

        foreach ($data as $item) {
            $result["filoblu_{$item['COLUMN_NAME']}"] = ucwords(str_replace('_', ' ',  $item['COLUMN_NAME']));
        }

        natsort($result);
        return $result;
    }
}
